/*
** Module   : WeightedToken.java
** Abstract : An interface marking a weighted security token.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20140513 Created initial version.
*/

package com.goldencode.p2j.security;


/**
 * Interface marking a weighted security token.  A context-local var needs to implement this
 * interface, if it needs to be cleaned up in a specific order, during context reset.
 */
public interface WeightedToken
{
   /**
    * Get the weight of this context-local var.  The variables will be ordered by their 
    * {@link WeightFactor weight}, when security context is being reset.  Note that the security 
    * context reset can't ensure a specific order among vars with the same weight.
    * 
    * @return   The weight of this context-local var.  By default, it returns 
    *           {@link WeightFactor#NO_DEPENDENCY} - thus, unless overwritten, the context-local 
    *           var will be cleaned up first.
    */
   public WeightFactor getWeight();
}
